@@ -37,6 +37,17 @@
 
 "water"
 
+#' Small Digital Elevation Model
+#'
+#' A \code{stars} object representing a 13*11 Digital Elevation Model (DEM)
+#'
+#' @format A \code{stars} object with 1 attribute:
+#' \describe{
+#'   \item{elevation}{Elevation above sea level, in meters}
+#' }
+
+"dem"
+
 
 
 
