@@ -37,16 +37,8 @@ l
 plot(st_geometry(towns[1:5, ]), col = "darkgrey")
 plot(st_geometry(l), add = TRUE)
 plot(st_geometry(cities), col = "red", add = TRUE)
-text(
-  st_coordinates(cities)[, 1], 
-  st_coordinates(cities)[, 2], 
-  1:3, col = "red", pos = 4
-)
-text(
-  st_coordinates(towns[1:5, ])[, 1], 
-  st_coordinates(towns[1:5, ])[, 2], 
-  1:5, pos = 4
-)
+text(st_coordinates(cities)[, 1], st_coordinates(cities)[, 2], 1:3, col = "red", pos = 4)
+text(st_coordinates(towns[1:5, ])[, 1], st_coordinates(towns[1:5, ])[, 2], 1:5, pos = 4)
 
 ## ------------------------------------------------------------------------
 nn = st_nn(cities, towns[1:5, ], sparse = FALSE, progress = FALSE)
@@ -56,21 +48,16 @@ nn
 nn = st_nn(cities, towns[1:5, ], k = 2, progress = FALSE)
 nn
 
+## ------------------------------------------------------------------------
 nn = st_nn(cities, towns[1:5, ], sparse = FALSE, k = 2, progress = FALSE)
 nn
 
 ## ------------------------------------------------------------------------
-nn = st_nn(
-  cities, towns[1:5, ], sparse = FALSE, k = 2, returnDist = TRUE, 
-  progress = FALSE
-)
+nn = st_nn(cities, towns[1:5, ], k = 2, returnDist = TRUE, progress = FALSE)
 nn
 
 ## ------------------------------------------------------------------------
-nn = st_nn(
-  cities, towns[1:5, ], sparse = FALSE, k = 2, returnDist = TRUE, maxdist = 50000, 
-  progress = FALSE
-)
+nn = st_nn(cities, towns[1:5, ], k = 2, maxdist = 50000, progress = FALSE)
 nn
 
 ## ---- results='hide'-----------------------------------------------------
@@ -94,7 +81,7 @@ nn = st_nn(water[-1, ], towns, k = 20, progress = FALSE)
 ## ---- warning=FALSE------------------------------------------------------
 l = st_connect(water[-1, ], towns, ids = nn, progress = FALSE, dist = 100)
 
-## ----water_towns, fig.align='center', fig.width=5, fig.height=7, warning=FALSE, fig.cap="Nearest 20 \\texttt{towns} features from each \\texttt{water} polygon"----
+## ----water_towns, fig.align='center', fig.width=5, fig.height=5, warning=FALSE, fig.cap="Nearest 20 \\texttt{towns} features from each \\texttt{water} polygon"----
 plot(st_geometry(water[-1, ]), col = "lightblue", border = "grey")
 plot(st_geometry(towns), col = "darkgrey", add = TRUE)
 plot(st_geometry(l), col = "red", add = TRUE)
